@@ -13,7 +13,7 @@ from scipy.sparse.linalg import svds
 from scipy.stats import pearsonr
 from joblib import Parallel, delayed
 from collections import OrderedDict, Counter
-from tqdm import tqdm, tqdm_notebook
+from tqdm import tqdm, notebook 
 
 from .utils import Utils
 from .window import WindowWeights
@@ -79,7 +79,7 @@ class svd2vec:
                  window=10,
                  dyn_window_weight=WINDOW_WEIGHT_WORD2VEC,
                  cds_alpha=0.75,
-                 neg_k_shift=5,
+                 neg_k_shift=1,
                  eig_p_weight=0,
                  nrm_type=NRM_SCHEME_ROW,
                  sub_threshold=1e-5,
@@ -210,8 +210,8 @@ class svd2vec:
             # solves a bug in jupyter notebooks
             # https://github.com/tqdm/tqdm/issues/485#issuecomment-473338308
             print('\r', end='', flush=True)
-        func   = tqdm_notebook if notebook else tqdm
-        format = None if notebook else "{desc: <30} {percentage:3.0f}%  {bar}"
+        func   = notebook.tqdm_notebook if notebook else tqdm
+        format = "{desc: <30} {percentage:3.0f}%  {bar}"
         return func(
             iterable=yielder,
             desc=desc,
